==> frmaTools_1.0.0.zip: frmaTools/doc/frmaTools.R <==
###################################################
### chunk number 1: 
###################################################
library(frmaTools)


###################################################
### chunk number 2: 
###################################################
library(frmaExampleData)
data(list="AffyBatch133a")


###################################################
### chunk number 3: 
###################################################
batch.id <- rep(1:3, each=3)


###################################################
### chunk number 4: 
###################################################
object <- makeVectors(AffyBatch133a, batch.id)


###################################################
### chunk number 5: 
###################################################
library(frmaTools)


###################################################
### chunk number 6: 
###################################################
library(frmaExampleData)
data(list="AffyBatch133atag")


###################################################
### chunk number 7: 
###################################################
object <- convertPlatform(AffyBatch133atag, "hgu133a")


###################################################
### chunk number 8: 
###################################################
library(frmaTools)


###################################################
### chunk number 9: 
###################################################
library(frmaExampleData)
data(list="AffyBatch133plus2")


###################################################
### chunk number 10: 
###################################################
e <- hgu133plus2ASaFrma(AffyBatch133plus2)

==> frmaTools_1.2.0.zip: frmaTools/doc/frmaTools.R <==
###################################################
### chunk number 1: 
###################################################
#line 69 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
library(frmaTools)


###################################################
### chunk number 2: 
###################################################
#line 73 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
library(frmaExampleData)
data(list="AffyBatch133a")


###################################################
### chunk number 3: 
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
batch.id <- rep(1:3, each=3)


###################################################
### chunk number 4: 
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
object <- makeVectors(AffyBatch133a, batch.id)


###################################################
### chunk number 5: 
###################################################
#line 108 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
library(frmaTools)


###################################################
### chunk number 6: 
###################################################
#line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
library(frmaExampleData)
data(list="AffyBatch133atag")


###################################################
### chunk number 7: 
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
object <- convertPlatform(AffyBatch133atag, "hgu133a")


###################################################
### chunk number 8: 
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
library(frmaTools)


###################################################
### chunk number 9: 
###################################################
#line 139 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
library(frmaExampleData)
data(list="AffyBatch133plus2")


###################################################
### chunk number 10: 
###################################################
#line 144 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpjb6eJB/R.INSTALL758f74f8/frmaTools/inst/doc/frmaTools.Rnw"
e <- hgu133plus2ASaFrma(AffyBatch133plus2)
